==> choqok-1.5.85.tar.xz: choqok-1.5.85/plugins/shorteners/yourls/yourls.h <==
/*
This file is part of Choqok, the KDE micro-blogging client

Copyright (C) 2010-2011 Marcello Ceschia <marcelloceschia@users.sourceforge.net>
Copyright (C) 2010-2012 Mehrdad Momeny <mehrdad.momeny@gmail.com>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License or (at your option) version 3 or any later version
accepted by the membership of KDE e.V. (or its successor approved
by the membership of KDE e.V.), which shall act as a proxy
defined in Section 14 of version 3 of the license.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see http://www.gnu.org/licenses/
*/
#ifndef YOURLS_H
#define YOURLS_H

#include <QVariantList>
#include <QUrlQuery>

#include "shortener.h"

/**
@author Marcello Ceschia \<marcelloceschia@users.sourceforge.net\>
@author Mehrdad Momeny \<mehrdad.momeny@gmail.com\>
*/
class Yourls : public Choqok::Shortener
{
    Q_OBJECT

public:
    Yourls(QObject *parent, const QVariantList &args);
    ~Yourls();

    virtual QString shorten(const QString &url);

private Q_SLOTS:
    void reloadConfigs();
private:
    QString password;
};

#endif

==> choqok_1.7.0.orig.tar.xz: choqok-1.7.0/plugins/shorteners/yourls/yourls.h <==
/*
This file is part of Choqok, the KDE micro-blogging client

Copyright (C) 2010-2011 Marcello Ceschia <marcelloceschia@users.sourceforge.net>
Copyright (C) 2010-2012 Mehrdad Momeny <mehrdad.momeny@gmail.com>

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License as
published by the Free Software Foundation; either version 2 of
the License or (at your option) version 3 or any later version
accepted by the membership of KDE e.V. (or its successor approved
by the membership of KDE e.V.), which shall act as a proxy
defined in Section 14 of version 3 of the license.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, see http://www.gnu.org/licenses/
*/
#ifndef YOURLS_H
#define YOURLS_H

#include <QVariantList>
#include <QUrlQuery>

#include "shortener.h"

/**
@author Marcello Ceschia \<marcelloceschia@users.sourceforge.net\>
@author Mehrdad Momeny \<mehrdad.momeny@gmail.com\>
*/
class Yourls : public Choqok::Shortener
{
    Q_OBJECT

public:
    Yourls(QObject *parent, const QVariantList &args);
    ~Yourls();

    virtual QString shorten(const QString &url) override;

private Q_SLOTS:
    void reloadConfigs();
private:
    QString password;
};

#endif
